seqmagick-package: seqmagick: Sequence Manipulation Utilities

seqmagick-packageR Documentation

seqmagick: Sequence Manipulation Utilities

Description

Tools for reading and writing biological sequences in multiple formats, including 'FASTA', 'PHYLIP', 'CLUSTAL', 'STOCKHOLM', 'MEGA' and 'GenBank'. Supports interleaved and sequential layouts where applicable, converts between formats, and manipulates sequence sets (e.g., filtering by patterns and computing consensus sequences from alignments). Also includes functions to download nucleotide records from NCBI by accession.

Author(s)

Maintainer: Guangchuang Yu guangchuangyu@gmail.com (ORCID)

See Also

Useful links:


seqmagick documentation built on Jan. 31, 2026, 9:06 a.m.