| seqmagick-package | R Documentation |
Tools for reading and writing biological sequences in multiple formats, including 'FASTA', 'PHYLIP', 'CLUSTAL', 'STOCKHOLM', 'MEGA' and 'GenBank'. Supports interleaved and sequential layouts where applicable, converts between formats, and manipulates sequence sets (e.g., filtering by patterns and computing consensus sequences from alignments). Also includes functions to download nucleotide records from NCBI by accession.
Maintainer: Guangchuang Yu guangchuangyu@gmail.com (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.